Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
/Users/eugene/Development/robotnikmq/robotnikmq/__init__.py | 9 | 0 | 0 | 0 | 0 | 100%
/Users/eugene/Development/robotnikmq/robotnikmq/config.py | 85 | 15 | 0 | 34 | 5 | 82%
/Users/eugene/Development/robotnikmq/robotnikmq/core.py | 146 | 22 | 0 | 53 | 5 | 86%
/Users/eugene/Development/robotnikmq/robotnikmq/error.py | 14 | 5 | 0 | 0 | 0 | 64%
/Users/eugene/Development/robotnikmq/robotnikmq/log.py | 4 | 0 | 0 | 0 | 0 | 100%
/Users/eugene/Development/robotnikmq/robotnikmq/rpc_client.py | 38 | 25 | 0 | 12 | 0 | 30%
/Users/eugene/Development/robotnikmq/robotnikmq/rpc_server.py | 180 | 105 | 0 | 116 | 0 | 44%
/Users/eugene/Development/robotnikmq/robotnikmq/subscriber.py | 67 | 0 | 9 | 24 | 2 | 98%
/Users/eugene/Development/robotnikmq/robotnikmq/topic.py | 21 | 0 | 0 | 8 | 0 | 100%
/Users/eugene/Development/robotnikmq/robotnikmq/utils.py | 7 | 0 | 6 | 2 | 0 | 100%
Total | 571 | 172 | 15 | 249 | 12 | 69%

No items found using the specified filter.